pub enum QueryRule {
Whole(String),
Items(BTreeMap<String, QueryPredicate>),
}Expand description
The ? key, which Apple allows to be either a pattern or a dictionary of predicates.
Variants
Whole(String)
A single pattern matched against the whole query string.
Items(BTreeMap<String, QueryPredicate>)
Named predicates that must all be satisfied.